@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.002_002'; # TRIAL VERSION
+our $VERSION = '0.003_001'; # TRIAL VERSION
 
 sub new {
     my ($class, %args) = @_;
@@ -31,7 +31,7 @@ __END__
 
 =head1 NAME
 
-YAML::PP - YAML Parser and Loader
+YAML::PP - YAML Framework
 
 =head1 SYNOPSIS
 
@@ -39,24 +39,34 @@ WARNING: This is highly experimental.
 
 Here are a few examples of what you can do right now:
 
-    # Load YAML into a very simple data structure
-    yaml-pp-p5-load < file.yaml
-
     # The loader offers JSON::PP, boolean.pm or pureperl 1/0 (default)
     # for booleans
     my $yppl = YAML::PP::Loader->new(boolean => 'JSON::PP');
     my ($data1, $data2) = $yppl->load($yaml);
 
+    my $yppd = YAML::PP::Dumper->new();
+    my $yaml = $yppd->dump($data1, $data2);
+
+Some utility scripts:
+
+    # Load YAML into a very simple data structure
+    yaml-pp-p5-load < file.yaml
+
+    # Load and dump
+    yaml-pp-p5-load-dump < file.yaml
+
     # Print the events from the parser in yaml-test-suite format
     yaml-pp-p5-events < file.yaml
 
+
 =head1 DESCRIPTION
 
 This is Yet Another YAML Parser. For why this project was started, see
 L<"WHY">.
 
-This project contains a Parser L<YAML::PP::Parser> and a Loader
-L<YAML::PP::Loader>.
+This project contains a Parser L<YAML::PP::Parser>, a Loader
+L<YAML::PP::Loader>, a Dumper L<YAML::PP::Dumper> and Emitter
+L<YAML::PP::Emitter>.
 
 =head2 YAML::PP::Parser
 
@@ -172,11 +182,35 @@ wish to be able to keep the comments.
 
 =back
 
+=head2 YAML::PP::Dumper, YAML::PP::Emitter
+
+This is also pretty simple so far. Any string containing something
+other than C<0-9a-zA-Z.-> will be dumped with double quotes.
+
+It will recognize JSON::PP::Boolean and boolean.pm objects and dump them
+correctly.
+
+The layout is like libyaml output:
+
+    key:
+    - a
+    - b
+    - c
+    ---
+    - key1: 1
+      key2: 2
+      key3: 3
+    ---
+    - - a1
+      - a2
+    - - b1
+      - b2
+
+
 =head1 NUMBERS
 
 Compare the output of the following YAML Loaders and JSON::XS dump:
 
-
     use JSON::XS;
     use Devel::Peek;
 
@@ -193,7 +227,7 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     my $d1 = YAML::XS::Load($yaml);
     my $d2 = YAML::Load($yaml);
     my $d3 = YAML::Syck::Load($yaml);
-    my $d4 = YAML::Tiny->read_string($yaml);
+    my $d4 = YAML::Tiny->read_string($yaml)->[0];
     my $d5 = YAML::PP::Loader->new->load($yaml);
 
     Dump $d1->{foo};
@@ -208,36 +242,32 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     say encode_json($d4);
     say encode_json($d5);
 
-    SV = PVIV(0x564f09465c00) at 0x564f09460780
+    SV = PVIV(0x55bbaff2bae0) at 0x55bbaff26518
       REFCNT = 1
       FLAGS = (IOK,POK,pIOK,pPOK)
       IV = 23
-      PV = 0x564f0945a600 "23"\0
+      PV = 0x55bbb06e67a0 "23"\0
       CUR = 2
       LEN = 10
-
-    SV = PVMG(0x5654d491dd80) at 0x5654d4aca4c8
+    SV = PVMG(0x55bbb08959b0) at 0x55bbb08fc6e8
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
       NV = 0
       PV = 0
-
-    SV = IV(0x564f6fab37d0) at 0x564f6fab37e0
+    SV = IV(0x55bbaffcb3b0) at 0x55bbaffcb3c0
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
-
-    SV = PVMG(0x5640b45a42a0) at 0x5640b4594250
+    SV = PVMG(0x55bbaff2f1f0) at 0x55bbb08fc8c8
       REFCNT = 1
       FLAGS = (POK,pPOK,UTF8)
       IV = 0
       NV = 0
-      PV = 0x5640b45a21f0 "23"\0 [UTF8 "23"]
+      PV = 0x55bbb0909d00 "23"\0 [UTF8 "23"]
       CUR = 2
       LEN = 10
-
-    SV = PVMG(0x564f09b5cbc0) at 0x564f09d473c0
+    SV = PVMG(0x55bbaff2f6d0) at 0x55bbb08b2c10
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
@@ -247,8 +277,9 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     {"foo":"23"}
     {"foo":23}
     {"foo":23}
-    {"foo":23}
     {"foo":"23"}
+    {"foo":23}
+
 
 
 =head1 WHY
