@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.002_002'; # TRIAL VERSION
+our $VERSION = '0.003_001'; # TRIAL VERSION
 
 use YAML::PP::Render;
 
@@ -793,6 +793,10 @@ sub parse_plain_multi {
     };
 }
 
+my %control = (
+    '\\' => '\\', n => "\n", t => "\t", r => "\r", b => "\b",
+    'x0a' => "\n", 'x0d' => "\r",
+);
 sub parse_map {
     my ($self, %args) = @_;
     my $yaml = $self->yaml;
@@ -840,8 +844,10 @@ sub parse_map {
         if ($key =~ s/^(["'])(.*)\1$/$2/) {
             $key_style = $1;
         }
-        if ($key_style ne '"') {
-            $key =~ s/\\/\\\\/g;
+        if ($key_style eq '"') {
+            $key =~ s/\\(x0d|x0a|[\\ntrb])/$control{ $1 }/g;
+            $key =~ s/\\"/"/g;
+            $key =~ s/\\u([A-Fa-f0-9]+)/chr(oct("x$1"))/eg;
         }
         if ($tag_anchor) {
             $anchor = $self->anchor and $self->set_anchor(undef);
@@ -1068,7 +1074,7 @@ my %event_to_method = (
     SEQ => 'sequence',
     DOC => 'document',
     STR => 'stream',
-    VAL => 'value',
+    VAL => 'scalar',
     ALI => 'alias',
 );
 
@@ -1091,7 +1097,7 @@ sub begin {
         }
     }
     TRACE and $self->debug_event("------------->> BEGIN $event ($offset) @content");
-    $self->callback->($self, "begin_" . $event_to_method{ $event_name }
+    $self->callback->($self, $event_to_method{ $event_name } . "_start_event"
         => { %info, content => $content[0] });
     $self->push_events($event, $offset);
     TRACE and $self->debug_events;
@@ -1102,7 +1108,7 @@ sub end {
     $self->pop_events($event);
     TRACE and $self->debug_event("-------------<< END   $event @{[$content//'']}");
     return if $event eq 'END';
-    $self->callback->($self, "end_" . $event_to_method{ $event }
+    $self->callback->($self, $event_to_method{ $event } . "_end_event"
         => { type => $event, content => $content });
     if ($event eq 'DOC') {
         $self->set_tagmap({
@@ -1116,7 +1122,7 @@ sub event {
     TRACE and $self->debug_event("------------- EVENT @{[ $self->event_to_test_suite($event)]}");
 
     my ($type, $info) = @$event;
-    $self->callback->($self, $event_to_method{ $type }, $info);
+    $self->callback->($self, $event_to_method{ $type } . "_event", $info);
 }
 
 sub event_to_test_suite {
@@ -1126,7 +1132,7 @@ sub event_to_test_suite {
         my $string;
         my $type = $info->{type};
         my $content = $info->{content};
-        if ($ev =~ m/^begin/) {
+        if ($ev =~ m/start/) {
             $string = "+$type";
             if (defined $info->{anchor}) {
                 $string .= " &$info->{anchor}";
@@ -1136,11 +1142,11 @@ sub event_to_test_suite {
             }
             $string .= " $content" if defined $content;
         }
-        elsif ($ev =~ m/^end_/) {
+        elsif ($ev =~ m/end/) {
             $string = "-$type";
             $string .= " $content" if defined $content;
         }
-        elsif ($ev eq 'value') {
+        elsif ($ev eq 'scalar_event') {
             $string = '=VAL';
             if (defined $info->{anchor}) {
                 $string .= " &$info->{anchor}";
@@ -1148,9 +1154,19 @@ sub event_to_test_suite {
             if (defined $info->{tag}) {
                 $string .= " $info->{tag}";
             }
+            if (defined $content) {
+                $content =~ s/\\/\\\\/g;
+                $content =~ s/\t/\\t/g;
+                $content =~ s/\r/\\r/g;
+                $content =~ s/\n/\\n/g;
+                $content =~ s/[\b]/\\b/g;
+            }
+            else {
+                $content = '';
+            }
             $string .= ' ' . $info->{style} . ($content // '');
         }
-        elsif ($ev eq 'alias') {
+        elsif ($ev eq 'alias_event') {
             $string = "=ALI *$content";
         }
         return $string;
